# ASRT_SDK_Python3

ASRT Python3 SDK

[![Python package](https://github.com/nl8590687/ASRT_SDK_Python3/actions/workflows/python-package.yml/badge.svg)](https://github.com/nl8590687/ASRT_SDK_Python3/actions/workflows/python-package.yml)
[![Pylint](https://github.com/nl8590687/ASRT_SDK_Python3/actions/workflows/pylint.yml/badge.svg)](https://github.com/nl8590687/ASRT_SDK_Python3/actions/workflows/pylint.yml)

[ASRT语音识别项目主页](https://asrt.ailemon.net/) | [ASRT项目文档](https://asrt.ailemon.net/docs/)

## 安装
```
$ pip install asrt-sdk
```
